@@ -1,11 +1,11 @@
 #' @importFrom utils head
 removezeros <- function(x){ # e.g c(3,1,0,0) -> c(3,1)
   i <- match(0L, x)
-  if(!is.na(i)) return(head(x,i-1L)) else return(x)
+  if(!is.na(i)) head(x, i-1L) else x
 }
 
 arePositiveIntegers <- function(x){
-  all(x>=0 & floor(x) == x)
+  all(x >= 0 & floor(x) == x)
 }
 
 isPartition <- function(x){
@@ -16,7 +16,7 @@ checkPartition <- function(x){
   if(isPartition(x)){
     return(removezeros(x))
   }else{
-    stop("`lambda` is not a partition", call. = FALSE)
+    stop("`lambda` is not a partition.", call. = FALSE)
   }
 }
 
@@ -28,14 +28,15 @@ isSYT <- function(syt){
   contents <- unlist(syt)
   N <- length(contents)
   is.list(syt) &&
-  setequal(contents, 1L:N) &&
+    isPartition(lengths(syt)) &&
+    setequal(contents, 1L:N) &&
     checkSYTrows(syt) &&
     checkSYTrows(.dualsyt(syt))
 }
 
 checkSYT <- function(syt){
   if(!isSYT(syt)){
-    stop("Not a standard Young tableau", call. = FALSE)
+    stop("Not a standard Young tableau.", call. = FALSE)
   }else{
     return(invisible())
   }
